manyqr

package module
v0.0.0-...-28da916 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 27, 2026 License: Apache-2.0 Imports: 5 Imported by: 0

README

The ManyQr

This tool makes many QRs for the project AutoTracking

Usage

  1. install libs:
go mode tidy

2.Place an XLSX file in the project root containing student IDs in column A and their names in column B.

3.Configure config.env and run the file by entering the course name in main.go.

4.NOW THIS ITS LIB FOR AUTOTRACKING. IF YOU WANT TO TO USE IT YOU MUST EXPLORE MY CODE!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Gen

func Gen(cfgfile structs.ConfigFile, cfgqr structs.ConfigQR, cfgzip structs.ConfigZip)

func LazyGen

func LazyGen(course, link string)

Types

This section is empty.

Directories

Path Synopsis

Jump to